#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-postgresql
version:              2.13.5.2
visibility:           public
id:                   persistent-postgresql-2.13.5.2-LKL0exTOeYpBWj7Qen7oEa
key:                  persistent-postgresql-2.13.5.2-LKL0exTOeYpBWj7Qen7oEa
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Felipe Lessa, Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Backend for the persistent library using postgresql.
description:          Based on the postgresql-simple package
category:             Database, Yesod
abi:                  6f6cd1134bf68c3ca9477fa65a2381c6
exposed:              True
exposed-modules:
    Database.Persist.Postgresql Database.Persist.Postgresql.Internal
    Database.Persist.Postgresql.JSON

import-dirs:
    /usr/lib/ghc-9.6.6/site-local/persistent-postgresql-2.13.5.2

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/persistent-postgresql-2.13.5.2

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/persistent-postgresql-2.13.5.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-postgresql
hs-libraries:         HSpersistent-postgresql-2.13.5.2-LKL0exTOeYpBWj7Qen7oEa
depends:
    aeson-2.2.1.0-Def4REbZAAu5MJxZQtCFDo
    attoparsec-0.14.4-8ZKlPX7xLQdALFlvUv2KV7 base-4.18.2.1
    blaze-builder-0.4.4.1-6X0A9ZG2uxn56CMhJtY4oY bytestring-0.11.5.3
    conduit-1.3.6.1-33PyKFsamc3EFWlmJ7D0Br containers-0.6.7
    monad-logger-0.3.42-Gz3nX5p8fJ29HPLriRpUQl mtl-2.3.1
    persistent-2.14.5.2-FAwgt6nNomG3D4QE8cObIU
    postgresql-libpq-0.9.5.0-6Abcvnlrbx38D8lE6uFyjU
    postgresql-simple-0.6.5.1-72Cui374WAuEXnjPYLie2y
    resource-pool-0.2.3.2-3ccZz0euPulCTweWIr0VFv
    resourcet-1.2.6-A7WR33a0Ijp2wXAvSf2FKK
    string-conversions-0.4.0.1-LTGnXQU7F9LF7QuuvvXPma text-2.0.2
    time-1.12.2 transformers-0.6.1.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    vault-0.3.1.6-LZWsK7dsgVF1l88n23pw8P

haddock-interfaces:
    /usr/share/doc/haskell-persistent-postgresql/html/persistent-postgresql.haddock

haddock-html:         /usr/share/doc/haskell-persistent-postgresql/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

